# Frequently Asked Questions

## Can I delete all my frames?

Yes! To do so, delete the `frames` file in your configuration folder (see [configuration](user-guide/configuration.md) to find its location).
